@@ -3,7 +3,7 @@
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2001,2002 Ananova Ltd
  * Copyright 2002,2003,2004,2005,2006,2007,2008 Olly Betts
- * Copyright 2006 Richard Boulton
+ * Copyright 2006,2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,6 +44,7 @@
 
 #include <stdlib.h> // For abs().
 
+#include <cstring>
 #include <vector>
 
 using namespace std;
@@ -180,14 +181,7 @@ Database::allterms_begin(const std::string & prefix) const
     if (internal.size() == 1)
 	RETURN(TermIterator(internal[0]->open_allterms(prefix)));
 
-    vector<TermList *> lists;
-
-    vector<Xapian::Internal::RefCntPtr<Database::Internal> >::const_iterator i;
-    for (i = internal.begin(); i != internal.end(); ++i) {
-	lists.push_back((*i)->open_allterms(prefix));
-    }
-
-    RETURN(TermIterator(new MultiAllTermsList(lists)));
+    RETURN(TermIterator(new MultiAllTermsList(internal, prefix)));
 }
 
 bool
@@ -318,7 +312,8 @@ Database::get_document(Xapian::docid did) const
     Xapian::doccount n = (did - 1) % multiplier; // which actual database
     Xapian::docid m = (did - 1) / multiplier + 1; // real docid in that database
 
-    RETURN(Document(internal[n]->open_document(m)));
+    // Open non-lazily so we throw DocNotFoundError if the doc doesn't exist.
+    RETURN(Document(internal[n]->open_document(m, false)));
 }
 
 bool
@@ -352,6 +347,41 @@ Database::get_description() const
     return "Database()";
 }
 
+// We sum the character frequency histogram absolute differences to compute a
+// lower bound on the edit distance.  Rather than counting each Unicode code
+// point uniquely, we use an array with VEC_SIZE elements and tally code points
+// modulo VEC_SIZE which can only reduce the bound we calculate.
+//
+// There will be a trade-off between how good the bound is and how large and
+// array is used (a larger array takes more time to clear and sum over).  The
+// value 64 is somewhat arbitrary - it works as well as 128 for the testsuite
+// but that may not reflect real world performance.  FIXME: profile and tune.
+
+#define VEC_SIZE 64
+
+static int
+freq_edit_lower_bound(const vector<unsigned> & a, const vector<unsigned> & b)
+{
+    int vec[VEC_SIZE];
+    memset(vec, 0, sizeof(vec));
+    vector<unsigned>::const_iterator i;
+    for (i = a.begin(); i != a.end(); ++i) {
+	++vec[(*i) % VEC_SIZE];
+    }
+    for (i = b.begin(); i != b.end(); ++i) {
+	--vec[(*i) % VEC_SIZE];
+    }
+    unsigned int total = 0;
+    for (size_t j = 0; j < VEC_SIZE; ++j) {
+	total += abs(vec[j]);
+    }
+    // Each insertion or deletion adds at most 1 to total.  Each transposition
+    // doesn't change it at all.  But each substitution can change it by 2 so
+    // we need to divide it by 2.  Rounding up is OK, since the odd change must
+    // be due to an actual edit.
+    return (total + 1) / 2;
+}
+
 // Word must have a trigram score at least this close to the best score seen
 // so far.
 #define TRIGRAM_SCORE_THRESHOLD 2
@@ -362,6 +392,7 @@ Database::get_spelling_suggestion(const string &word,
 {
     DEBUGAPICALL(string, "Database::get_spelling_suggestion",
 		 word << ", " << max_edit_distance);
+    if (word.size() <= 1) return string();
     AutoPtr<TermList> merger;
     for (size_t i = 0; i < internal.size(); ++i) {
 	TermList * tl = internal[i]->open_spelling_termlist(word);
@@ -377,8 +408,16 @@ Database::get_spelling_suggestion(const string &word,
     if (!merger.get()) RETURN(string());
 
     // Convert word to UTF-32.
+#ifdef __SUNPRO_CC
     vector<unsigned> utf32_word;
-    utf32_word.assign(Utf8Iterator(word), Utf8Iterator());
+    for (Utf8Iterator sunpro_it(word); sunpro_it != Utf8Iterator(); ++sunpro_it) {
+	utf32_word.push_back(*sunpro_it);
+    }
+#else
+    // Extra brackets needed to avoid this being misparsed as a function
+    // prototype.
+    vector<unsigned> utf32_word((Utf8Iterator(word)), Utf8Iterator());
+#endif
 
     vector<unsigned> utf32_term;
 
@@ -414,16 +453,22 @@ Database::get_spelling_suggestion(const string &word,
 	    // strictly.
 	    utf32_term.assign(Utf8Iterator(term), Utf8Iterator());
 
-	    if (abs((long)utf32_term.size() - (long)utf32_word.size())
+	    if (abs(long(utf32_term.size()) - long(utf32_word.size()))
 		    > edist_best) {
 		DEBUGLINE(SPELLING, "Lengths too different");
 		continue;
 	    }
 
+	    if (freq_edit_lower_bound(utf32_term, utf32_word) > edist_best) {
+		DEBUGLINE(SPELLING, "Rejected by character frequency test");
+		continue;
+	    }
+
 	    int edist = edit_distance_unsigned(&utf32_term[0],
-					       utf32_term.size(),
+					       int(utf32_term.size()),
 					       &utf32_word[0],
-					       utf32_word.size());
+					       int(utf32_word.size()),
+					       edist_best);
 	    DEBUGLINE(SPELLING, "Edit distance " << edist);
 	    // If we have an exact match, return an empty string since there's
 	    // no correction required.
@@ -512,6 +557,13 @@ Database::get_metadata(const string & key) const
     RETURN(internal[0]->get_metadata(key));
 }
 
+Xapian::TermIterator
+Database::metadata_keys_begin(const std::string &prefix) const
+{
+    DEBUGAPICALL(Xapian::TermIterator, "Database::metadata_keys_begin", "");
+    RETURN(TermIterator(internal[0]->open_metadata_keylist(prefix)));
+}
+
 ///////////////////////////////////////////////////////////////////////////
 
 WritableDatabase::WritableDatabase() : Database()
