@@ -2,6 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002,2003,2004,2005,2007 Olly Betts
+ * Copyright 2007 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +26,8 @@
 #include "quartz_utils.h"
 #include "bcursor.h"
 #include "database.h"
+#include "noreturn.h"
+#include "utils.h"
 
 /// Make a key for accessing the postlist.
 static void
@@ -98,6 +101,7 @@ class QPostlistChunkWriter {
 // Static functions
 
 /// Report an error when reading the posting list.
+XAPIAN_NORETURN(static void report_read_error(const char * position));
 static void report_read_error(const char * position)
 {
     if (position == 0) {
