@@ -1,21 +1,25 @@
 /* @file serialise-double.cc
  * @brief functions to serialise and unserialise a double
  */
-/* Copyright (C) 2006,2007 Olly Betts
+/* Copyright (C) 2006,2007,2008,2009 Olly Betts
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to
+ * deal in the Software without restriction, including without limitation the
+ * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
+ * sell copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+ * IN THE SOFTWARE.
  */
 
 #include <config.h>
@@ -56,7 +60,7 @@ using namespace std;
 # define MAX_MANTISSA_BYTES ((DBL_MANT_DIG + 1 + 1) / 2)
 # define MAX_EXP ((DBL_MAX_EXP + 1) / 2)
 # define MAX_MANTISSA (1 << ((DBL_MAX_EXP & 1) * 4))
-#elif
+#else
 # error FLT_RADIX is a value not currently handled (not 2 or 16)
 // # define MAX_MANTISSA_BYTES (sizeof(double) + 1)
 #endif
@@ -117,7 +121,7 @@ std::string serialise_double(double v)
     size_t n = result.size();
     do {
 	unsigned char byte = static_cast<unsigned char>(v);
-	result += (char)byte;
+	result += char(byte);
 	v -= double(byte);
 	v *= 256.0;
     } while (v != 0.0 && --maxbytes);
