@@ -33,6 +33,7 @@ using namespace std;
 #define PROG_NAME "quest"
 #define PROG_DESC "Xapian command line search tool"
 
+// Stopwords:
 static const char * sw[] = {
     "a", "about", "an", "and", "are", "as", "at",
     "be", "by",
@@ -60,6 +61,7 @@ static void show_usage() {
 int
 main(int argc, char **argv)
 {
+    const char * opts = "d:m:s:hv";
     static const struct option long_opts[] = {
 	{ "db",		required_argument, 0, 'd' },
 	{ "msize",	required_argument, 0, 'm' },
@@ -79,8 +81,7 @@ main(int argc, char **argv)
 	Xapian::Database db;
 
 	int c;
-	while ((c = gnu_getopt_long(argc, argv, "hvm:d:s:", long_opts, 0)) != EOF)
-	{
+	while ((c = gnu_getopt_long(argc, argv, opts, long_opts, 0)) != -1) {
 	    switch (c) {
 		case 'm':
 		    msize = atoi(optarg);
@@ -93,9 +94,10 @@ main(int argc, char **argv)
 		    try {
 			stemmer = Xapian::Stem(optarg);
 		    } catch (const Xapian::Error &) {
-			cerr << "Unknown stemming language '" << optarg << "'.\n";
-			cerr << "Available language names are: "
-			    << Xapian::Stem::get_available_languages() << endl;
+			cerr << "Unknown stemming language '" << optarg
+			     << "'.\n"
+				"Available language names are: "
+			     << Xapian::Stem::get_available_languages() << endl;
 			exit(1);
 		    }
 		    break;
@@ -118,31 +120,31 @@ main(int argc, char **argv)
 	    exit(1);
 	}
 
-	Xapian::Enquire enquire(db);
+	Xapian::QueryParser parser;
+	parser.set_database(db);
+	parser.set_default_op(Xapian::Query::OP_OR);
+	parser.set_stemmer(stemmer);
+	parser.set_stemming_strategy(Xapian::QueryParser::STEM_SOME);
+	parser.set_stopper(&mystopper);
 
-	try {
-	    Xapian::QueryParser parser;
-	    parser.set_database(db);
-	    parser.set_default_op(Xapian::Query::OP_OR);
-	    parser.set_stemmer(stemmer);
-	    parser.set_stemming_strategy(Xapian::QueryParser::STEM_SOME);
-	    parser.set_stopper(&mystopper);
-	    Xapian::Query query = parser.parse_query(argv[optind]);
-	    cout << "Query: " << query.get_description() << endl;
-	    enquire.set_query(query);
-	} catch (const char * error_msg) {
-	    cout << "Couldn't parse query: " << error_msg << endl;
-	    exit(1);
-	}
+	Xapian::Query query = parser.parse_query(argv[optind]);
+	cout << "Query: " << query.get_description() << endl;
+
+	Xapian::Enquire enquire(db);
+	enquire.set_query(query);
+
+	Xapian::MSet mset = enquire.get_mset(0, msize);
 
 	cout << "MSet:" << endl;
-	Xapian::MSet mset = enquire.get_mset(0, msize);
 	for (Xapian::MSetIterator i = mset.begin(); i != mset.end(); i++) {
 	    Xapian::Document doc = i.get_document();
 	    string data = doc.get_data();
 	    cout << *i << " [" << i.get_percent() << "%]\n" << data << "\n";
 	}
 	cout << flush;
+    } catch (const Xapian::QueryParserError & e) {
+	cout << "Couldn't parse query: " << e.get_msg() << endl;
+	exit(1);
     } catch (const Xapian::Error & err) {
 	cout << err.get_description() << endl;
 	exit(1);
