@@ -3,8 +3,8 @@
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007 Olly Betts
- * Copyright 2006 Richard Boulton
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009 Olly Betts
+ * Copyright 2006,2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -35,7 +35,6 @@
 #include <xapian/termiterator.h>
 #include <xapian/visibility.h>
 
-/// The Xapian library lives in the Xapian namespace.
 namespace Xapian {
 
 class Document;
@@ -304,12 +303,33 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 *
 	 *  @exception Xapian::InvalidArgumentError will be thrown if the
 	 *	       key supplied is empty.
-	 *
-	 *  @exception Xapian::UnimplementedError will be thrown if the
-	 *	       database backend in use doesn't support user-specified
-	 *	       metadata.
 	 */
 	std::string get_metadata(const std::string & key) const;
+
+	/** An iterator which returns all user-specified metadata keys.
+	 *
+	 *  When invoked on a Xapian::Database object representing multiple
+	 *  databases, currently only the metadata for the first is considered
+	 *  but this behaviour may change in the future.
+	 *
+	 *  If the backend doesn't support metadata, then this method returns
+	 *  an iterator which compares equal to that returned by
+	 *  metadata_keys_end().
+	 *
+	 *  @param prefix   If non-empty, only keys with this prefix are
+	 *		    returned.
+	 *
+	 *  @exception Xapian::UnimplementedError will be thrown if the
+	 *			backend implements user-specified metadata, but
+	 *			doesn't implement iterating its keys (currently
+	 *			this happens for the InMemory backend).
+	 */
+	Xapian::TermIterator metadata_keys_begin(const std::string &prefix = "") const;
+
+	/// Corresponding end iterator to metadata_keys_begin().
+	Xapian::TermIterator metadata_keys_end(const std::string & = "") const {
+	    return Xapian::TermIterator(NULL);
+	}
 };
 
 /** This class provides read/write access to a database.
@@ -343,6 +363,12 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  - Xapian::DB_CREATE_OR_OVERWRITE overwrite existing db; create if
 	 *    none exists
 	 *  - Xapian::DB_OPEN open for read/write; fail if no db exists
+	 *
+	 *  @exception Xapian::DatabaseCorruptError will be thrown if the
+	 *             database is in a corrupt state.
+	 *
+	 *  @exception Xapian::DatabaseLockError will be thrown if a lock
+	 *	       couldn't be acquired on the database.
 	 */
 	WritableDatabase(const std::string &path, int action);
 
@@ -389,16 +415,17 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *
 	 *  Note that flush need not be called explicitly: it will be called
 	 *  automatically when the database is closed, or when a sufficient
-	 *  number of modifications have been made.
+	 *  number of modifications have been made.  By default, this is every
+	 *  10000 documents added, deleted, or modified.  This value is rather
+	 *  conservative, and if you have a machine with plenty of memory,
+	 *  you can improve indexing throughput dramatically by setting
+	 *  XAPIAN_FLUSH_THRESHOLD in the environment to a larger value.
 	 *
 	 *  @exception Xapian::DatabaseError will be thrown if a problem occurs
 	 *             while modifying the database.
 	 *
 	 *  @exception Xapian::DatabaseCorruptError will be thrown if the
 	 *             database is in a corrupt state.
-	 *
-	 *  @exception Xapian::DatabaseLockError will be thrown if a lock
-	 *	       couldn't be acquired on the database.
 	 */
 	void flush();
 
@@ -605,9 +632,11 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  term, the lowest document ID will be used for the document,
 	 *  otherwise a new document ID will be generated as for add_document.
 	 *
-	 *  The intended use is to allow UIDs from another system to easily
-	 *  be mapped to terms in Xapian, although this method probably has
-	 *  other uses.
+	 *  A major use is for convenience when UIDs from another system are
+	 *  mapped to terms in Xapian, although this method has other uses
+	 *  (for example, you could add a "deletion date" term to documents at
+	 *  index time and use this method to delete all documents due for
+	 *  deletion on a particular date).
 	 *
 	 *  Note that changes to the database won't be immediately committed to
 	 *  disk; see flush() for more details.
@@ -713,6 +742,10 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *
 	 *  @exception Xapian::InvalidArgumentError will be thrown if the
 	 *             key supplied is empty.
+	 *
+	 *  @exception Xapian::UnimplementedError will be thrown if the
+	 *             database backend in use doesn't support user-specified
+	 *             metadata.
 	 */
 	void set_metadata(const std::string & key, const std::string & value);
 
