@@ -1,7 +1,7 @@
 /** \file  queryparser.h
  *  \brief parsing a user query string to build a Xapian::Query object
  */
-/* Copyright (C) 2005,2006,2007,2008 Olly Betts
+/* Copyright (C) 2005,2006,2007,2008,2009 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -88,9 +88,9 @@ struct XAPIAN_VISIBILITY_DEFAULT ValueRangeProcessor {
     /// Destructor.
     virtual ~ValueRangeProcessor();
 
-    /** See if <begin>..<end> is a valid value range.
+    /** Check for a valid range of this type.
      *
-     *  If this ValueRangeProcessor recognises <begin>..<end> it returns the
+     *  If this ValueRangeProcessor recognises BEGIN..END it returns the
      *  value number of range filter on.  Otherwise it returns
      *  Xapian::BAD_VALUENO.
      */
@@ -142,9 +142,9 @@ class XAPIAN_VISIBILITY_DEFAULT DateValueRangeProcessor : public ValueRangeProce
 			    int epoch_year_ = 1970)
 	: valno(valno_), prefer_mdy(prefer_mdy_), epoch_year(epoch_year_) { }
 
-    /** See if <begin>..<end> is a valid date value range.
+    /** Check for a valid range of this type.
      *
-     *  If <begin>..<end> is a sensible date range, this method returns the
+     *  If BEGIN..END is a sensible date range, this method returns the
      *  value number of range filter on.  Otherwise it returns
      *  Xapian::BAD_VALUENO.
      */
@@ -154,7 +154,7 @@ class XAPIAN_VISIBILITY_DEFAULT DateValueRangeProcessor : public ValueRangeProce
 // Xapian 1.0.0 and 1.0.1 had a conceptually broken implementation of
 // NumberValueRangeProcessor which we quickly told people to avoid using.  But
 // to keep ABI compatibility, we should keep it around until the next
-// incompatible ABI change (probably 1.1.0).  So we put the new
+// incompatible ABI change (in 1.1.0).  So we put the new
 // NumberValueRangeProcessor in a subnamespace and then pull it into this one
 // with "using v102::NumberValueRangeProcessor".  The old
 // NumberValueRangeProcessor still exists with default visibility, but isn't
@@ -222,9 +222,9 @@ class XAPIAN_VISIBILITY_DEFAULT NumberValueRangeProcessor : public ValueRangePro
 			      bool prefix_ = true)
 	: valno(valno_), prefix(prefix_), str(str_) { }
 
-    /** See if <begin>..<end> is a valid numeric value range.
+    /** Check for a valid range of this type.
      *
-     *  If <begin>..<end> is a valid numeric value range, and has the
+     *  If BEGIN..END is a valid numeric value range, and has the
      *  appropriate prefix or suffix (if specified) required for this
      *  NumberValueRangeProcessor, this method returns the value number of
      *  range filter on, and sets begin and end to the appropriate serialised
@@ -318,7 +318,15 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
 	 *
 	 *  NB: You must also call set_database() for this to work.
 	 */
-	FLAG_AUTO_MULTIWORD_SYNONYMS = 1024 | FLAG_AUTO_SYNONYMS
+	FLAG_AUTO_MULTIWORD_SYNONYMS = 1024 | FLAG_AUTO_SYNONYMS,
+
+	/** The default flags.
+	 *
+	 *  Used if you don't explicitly pass any to @a parse_query().
+	 *
+	 *  Added in Xapian 1.0.11.
+	 */
+	FLAG_DEFAULT = FLAG_PHRASE|FLAG_BOOLEAN|FLAG_LOVEHATE
     } feature_flag;
 
     typedef enum { STEM_NONE, STEM_SOME, STEM_ALL } stem_strategy;
@@ -381,7 +389,7 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *  @param query_string  A free-text query as entered by a user
      *  @param flags         Zero or more Query::feature_flag specifying
      *		what features the QueryParser should support.  Combine
-     *		multiple values with bitwise-or (|).
+     *		multiple values with bitwise-or (|) (default FLAG_DEFAULT).
      *	@param default_prefix  The default term prefix to use (default none).
      *		For example, you can pass "A" when parsing an "Author" field.
      */
@@ -410,9 +418,13 @@ class XAPIAN_VISIBILITY_DEFAULT QueryParser {
      *
      *  If any prefixes are specified for the empty field name (i.e. you
      *  call this method with an empty string as the first parameter)
-     *  these prefixes will be used as the default prefix.  If you do
-     *  this and also specify the @c default_prefix parameter to
-     *  @c parse_query(), then the @c default_prefix parameter will override.
+     *  these prefixes will be used for terms without a field specifier.
+     *  If you do this and also specify the @c default_prefix parameter to @c
+     *  parse_query(), then the @c default_prefix parameter will override.
+     *
+     *  If the prefix parameter is empty, then "field:word" will produce the
+     *  term "word" (and this can be one of several prefixes for a particular
+     *  field, or for terms without a field specifier).
      *
      *  If you call @c add_prefix() and @c add_boolean_prefix() for the
      *  same value of @a field, a @c Xapian::InvalidOperationError exception
