@@ -3,11 +3,11 @@
 */
 /* First off, code is included which follows the "include" declaration
 ** in the input file. */
-#line 1 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1 "queryparser/queryparser.lemony"
 
 /* queryparser.lemony: build a Xapian::Query object from a user query string.
  *
- * Copyright (C) 2004,2005,2006,2007,2008 Olly Betts
+ * Copyright (C) 2004,2005,2006,2007,2008,2009 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -154,7 +154,7 @@ class Term {
 	: state(state_), name(name_), prefixes(prefixes_), unstemmed(unstemmed_),
 	  stem(stem_), pos(pos_) { }
 
-    std::string make_term(const string & prefix) const;
+    string make_term(const string & prefix) const;
 
     void need_positions() {
 	if (stem == QueryParser::STEM_SOME) stem = QueryParser::STEM_NONE;
@@ -166,6 +166,14 @@ class Term {
 
     Query * as_wildcarded_query(State * state) const;
 
+    /** Build a query for a term at the very end of the query string when
+     *  FLAG_PARTIAL is in use.
+     *
+     *  This query should match documents containing any terms which start with
+     *  the characters specified, but should give a higher score to exact
+     *  matches (since the user might have finished typing - we simply don't
+     *  know).
+     */
     Query * as_partial_query(State * state_) const;
 
     Query get_query() const;
@@ -200,12 +208,11 @@ class State {
     }
 
     valueno value_range(Query & q, Term *a, Term *b) {
-	string start = a->name;
-	string end = b->name;
-	Xapian::valueno valno = Xapian::BAD_VALUENO;
 	list<ValueRangeProcessor *>::const_iterator i;
 	for (i = qpi->valrangeprocs.begin(); i != qpi->valrangeprocs.end(); ++i) {
-	    valno = (**i)(start, end);
+	    string start = a->name;
+	    string end = b->name;
+	    Xapian::valueno valno = (**i)(start, end);
 	    if (valno != Xapian::BAD_VALUENO) {
 		delete a;
 		delete b;
@@ -220,7 +227,7 @@ class State {
 	// more thought and probably a look at queries users actually
 	// enter.
 	error = "Unknown range operation";
-	return valno;
+	return Xapian::BAD_VALUENO;
     }
 
     Query::op default_op() const { return qpi->default_op; }
@@ -379,9 +386,13 @@ inline bool
 is_phrase_generator(unsigned ch)
 {
     // These characters generate a phrase search.
-    // Ordered mostly by frequency of calls to this function done when
-    // running queryparsertest.
-    return (ch && ch < 128 && strchr(".-/:\\@", ch) != NULL);
+    if (rare(ch == 0)) return false;
+    if (ch < 128) {
+	// Ordered mostly by frequency of calls to this function done when
+	// running queryparsertest.
+	return (strchr(".-/:\\@", ch) != NULL);
+    }
+    return Unicode::get_category(ch) == Xapian::Unicode::NON_SPACING_MARK;
 }
 
 inline bool
@@ -391,7 +402,7 @@ is_stem_preventer(unsigned ch)
 }
 
 inline bool
-should_stem(const std::string & term)
+should_stem(const string & term)
 {
     const unsigned int SHOULD_STEM_MASK =
 	(1 << Unicode::LOWERCASE_LETTER) |
@@ -1201,8 +1212,8 @@ class TermList {
      *  prefixes.  If so, we'll build a set of phrases, one using each prefix.
      *  This works around the limitation that a phrase cannot have multiple
      *  components which are "OR" combinations of terms, but is also probably
-     *  what users expect: ie, if a user specifies a phrase in a field, and that
-     *  field maps to multiple prefixes, the user probably wants a phrase
+     *  what users expect: i.e., if a user specifies a phrase in a field, and
+     *  that field maps to multiple prefixes, the user probably wants a phrase
      *  returned with all terms having one of those prefixes, rather than a
      *  phrase comprised of terms with differing prefixes.
      */
@@ -1319,7 +1330,7 @@ class TermList {
 	delete B;\
     } while (0)
 
-#line 1324 "queryparser/queryparser_internal.cc"
+#line 1335 "queryparser/queryparser_internal.cc"
 /* Next is all token values, in a form suitable for use by makeheaders.
 ** This section will be null unless lemon is run with the -m switch.
 */
@@ -1747,9 +1758,9 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 19:
     case 20:
     case 21:
-#line 1319 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1330 "queryparser/queryparser.lemony"
 {delete (yypminor->yy0);}
-#line 1754 "queryparser/queryparser_internal.cc"
+#line 1765 "queryparser/queryparser_internal.cc"
       break;
     case 24:
     case 25:
@@ -1757,28 +1768,28 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 28:
     case 30:
     case 31:
-#line 1390 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1401 "queryparser/queryparser.lemony"
 {delete (yypminor->yy13);}
-#line 1764 "queryparser/queryparser_internal.cc"
+#line 1775 "queryparser/queryparser_internal.cc"
       break;
     case 27:
     case 29:
-#line 1483 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1494 "queryparser/queryparser.lemony"
 {delete (yypminor->yy9);}
-#line 1770 "queryparser/queryparser_internal.cc"
+#line 1781 "queryparser/queryparser_internal.cc"
       break;
     case 32:
     case 33:
     case 35:
     case 36:
-#line 1684 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1695 "queryparser/queryparser.lemony"
 {(yypminor->yy1)->destroy();}
-#line 1778 "queryparser/queryparser_internal.cc"
+#line 1789 "queryparser/queryparser_internal.cc"
       break;
     case 34:
-#line 1718 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1729 "queryparser/queryparser.lemony"
 {(yypminor->yy60)->destroy();}
-#line 1783 "queryparser/queryparser_internal.cc"
+#line 1794 "queryparser/queryparser_internal.cc"
       break;
     default:  break;   /* If no destructor action specified: do nothing */
   }
@@ -2010,7 +2021,7 @@ static void yy_reduce(
   **     break;
   */
       case 0:
-#line 1372 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1383 "queryparser/queryparser.lemony"
 {
     // Save the parsed query in the State structure so we can return it.
     if (yymsp[0].minor.yy13) {
@@ -2020,30 +2031,30 @@ static void yy_reduce(
 	state->query = Query();
     }
 }
-#line 2025 "queryparser/queryparser_internal.cc"
+#line 2036 "queryparser/queryparser_internal.cc"
         break;
       case 1:
-#line 1382 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1393 "queryparser/queryparser.lemony"
 {
     // Handle a query string with no terms in.
     state->query = Query();
 }
-#line 2033 "queryparser/queryparser_internal.cc"
+#line 2044 "queryparser/queryparser_internal.cc"
         break;
       case 2:
       case 8:
-#line 1393 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1404 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy13; }
-#line 2039 "queryparser/queryparser_internal.cc"
+#line 2050 "queryparser/queryparser_internal.cc"
         break;
       case 3:
-#line 1396 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1407 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy13, yymsp[-2].minor.yy13, Query::OP_AND, yymsp[0].minor.yy13, "AND");   yy_destructor(4,&yymsp[-1].minor);
 }
-#line 2045 "queryparser/queryparser_internal.cc"
+#line 2056 "queryparser/queryparser_internal.cc"
         break;
       case 4:
-#line 1398 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1409 "queryparser/queryparser.lemony"
 {
     // 'NOT foo' -> '<alldocuments> NOT foo'
     if (!yymsp[-2].minor.yy13 && (state->flags & QueryParser::FLAG_PURE_NOT)) {
@@ -2052,39 +2063,39 @@ static void yy_reduce(
     BOOL_OP_TO_QUERY(yygotominor.yy13, yymsp[-2].minor.yy13, Query::OP_AND_NOT, yymsp[0].minor.yy13, "NOT");
   yy_destructor(5,&yymsp[-1].minor);
 }
-#line 2057 "queryparser/queryparser_internal.cc"
+#line 2068 "queryparser/queryparser_internal.cc"
         break;
       case 5:
-#line 1407 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1418 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy13, yymsp[-3].minor.yy13, Query::OP_AND_NOT, yymsp[0].minor.yy13, "AND NOT");   yy_destructor(4,&yymsp[-2].minor);
   yy_destructor(5,&yymsp[-1].minor);
 }
-#line 2064 "queryparser/queryparser_internal.cc"
+#line 2075 "queryparser/queryparser_internal.cc"
         break;
       case 6:
-#line 1410 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1421 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy13, yymsp[-2].minor.yy13, Query::OP_OR, yymsp[0].minor.yy13, "OR");   yy_destructor(2,&yymsp[-1].minor);
 }
-#line 2070 "queryparser/queryparser_internal.cc"
+#line 2081 "queryparser/queryparser_internal.cc"
         break;
       case 7:
-#line 1413 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1424 "queryparser/queryparser.lemony"
 { BOOL_OP_TO_QUERY(yygotominor.yy13, yymsp[-2].minor.yy13, Query::OP_XOR, yymsp[0].minor.yy13, "XOR");   yy_destructor(3,&yymsp[-1].minor);
 }
-#line 2076 "queryparser/queryparser_internal.cc"
+#line 2087 "queryparser/queryparser_internal.cc"
         break;
       case 9:
-#line 1422 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1433 "queryparser/queryparser.lemony"
 {
     // Set the argument to NULL, which enables the bool_arg-using rules in
     // expr above to report uses of AND, OR, etc which don't have two
     // arguments.
     yygotominor.yy13 = NULL;
 }
-#line 2086 "queryparser/queryparser_internal.cc"
+#line 2097 "queryparser/queryparser_internal.cc"
         break;
       case 10:
-#line 1434 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1445 "queryparser/queryparser.lemony"
 {
     yygotominor.yy13 = yymsp[0].minor.yy9->query;
     yymsp[0].minor.yy9->query = NULL;
@@ -2123,19 +2134,19 @@ static void yy_reduce(
     // FIXME what if yygotominor.yy13 && yygotominor.yy13->empty() (all terms are stopwords)?
     delete yymsp[0].minor.yy9;
 }
-#line 2128 "queryparser/queryparser_internal.cc"
+#line 2139 "queryparser/queryparser_internal.cc"
         break;
       case 11:
       case 29:
       case 31:
-#line 1473 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1484 "queryparser/queryparser.lemony"
 {
     yygotominor.yy13 = yymsp[0].minor.yy13;
 }
-#line 2137 "queryparser/queryparser_internal.cc"
+#line 2148 "queryparser/queryparser_internal.cc"
         break;
       case 12:
-#line 1485 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1496 "queryparser/queryparser.lemony"
 {
     Query range;
     Xapian::valueno valno = state->value_range(range, yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
@@ -2146,10 +2157,10 @@ static void yy_reduce(
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->filter[filter_group_id(valno)] = range;
 }
-#line 2151 "queryparser/queryparser_internal.cc"
+#line 2162 "queryparser/queryparser_internal.cc"
         break;
       case 13:
-#line 1496 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1507 "queryparser/queryparser.lemony"
 {
     Query range;
     Xapian::valueno valno = state->value_range(range, yymsp[-1].minor.yy0, yymsp[0].minor.yy0);
@@ -2161,28 +2172,28 @@ static void yy_reduce(
     Query & q = yygotominor.yy9->filter[filter_group_id(valno)];
     q = Query(Query::OP_OR, q, range);
 }
-#line 2166 "queryparser/queryparser_internal.cc"
+#line 2177 "queryparser/queryparser_internal.cc"
         break;
       case 14:
-#line 1508 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1519 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->query = yymsp[-1].minor.yy13;
     if (yymsp[0].minor.yy13) add_to_query(yygotominor.yy9->query, state->default_op(), yymsp[0].minor.yy13);
 }
-#line 2175 "queryparser/queryparser_internal.cc"
+#line 2186 "queryparser/queryparser_internal.cc"
         break;
       case 15:
-#line 1514 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1525 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = yymsp[-1].minor.yy9;
     // If yymsp[0].minor.yy13 is a stopword, there's nothing to do here.
     if (yymsp[0].minor.yy13) add_to_query(yygotominor.yy9->query, state->default_op(), yymsp[0].minor.yy13);
 }
-#line 2184 "queryparser/queryparser_internal.cc"
+#line 2195 "queryparser/queryparser_internal.cc"
         break;
       case 16:
-#line 1520 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1531 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     if (state->default_op() == Query::OP_AND) {
@@ -2192,10 +2203,10 @@ static void yy_reduce(
     }
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2197 "queryparser/queryparser_internal.cc"
+#line 2208 "queryparser/queryparser_internal.cc"
         break;
       case 17:
-#line 1529 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1540 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = yymsp[-2].minor.yy9;
     if (state->default_op() == Query::OP_AND) {
@@ -2208,57 +2219,57 @@ static void yy_reduce(
     }
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2213 "queryparser/queryparser_internal.cc"
+#line 2224 "queryparser/queryparser_internal.cc"
         break;
       case 18:
-#line 1541 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1552 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->hate = yymsp[0].minor.yy13;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2222 "queryparser/queryparser_internal.cc"
+#line 2233 "queryparser/queryparser_internal.cc"
         break;
       case 19:
-#line 1546 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1557 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = yymsp[-2].minor.yy9;
     add_to_query(yygotominor.yy9->hate, Query::OP_OR, yymsp[0].minor.yy13);
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2231 "queryparser/queryparser_internal.cc"
+#line 2242 "queryparser/queryparser_internal.cc"
         break;
       case 20:
-#line 1551 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1562 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->hate = new Query(yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2241 "queryparser/queryparser_internal.cc"
+#line 2252 "queryparser/queryparser_internal.cc"
         break;
       case 21:
-#line 1557 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1568 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = yymsp[-2].minor.yy9;
     add_to_query(yygotominor.yy9->hate, Query::OP_OR, yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
   yy_destructor(9,&yymsp[-1].minor);
 }
-#line 2251 "queryparser/queryparser_internal.cc"
+#line 2262 "queryparser/queryparser_internal.cc"
         break;
       case 22:
-#line 1563 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1574 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->filter[yymsp[0].minor.yy0->get_filter_group_id()] = yymsp[0].minor.yy0->get_query();
     delete yymsp[0].minor.yy0;
 }
-#line 2260 "queryparser/queryparser_internal.cc"
+#line 2271 "queryparser/queryparser_internal.cc"
         break;
       case 23:
-#line 1569 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1580 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = yymsp[-1].minor.yy9;
     // We OR filters with the same prefix...
@@ -2266,10 +2277,10 @@ static void yy_reduce(
     q = Query(Query::OP_OR, q, yymsp[0].minor.yy0->get_query());
     delete yymsp[0].minor.yy0;
 }
-#line 2271 "queryparser/queryparser_internal.cc"
+#line 2282 "queryparser/queryparser_internal.cc"
         break;
       case 24:
-#line 1577 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1588 "queryparser/queryparser.lemony"
 {
     // LOVE BOOLEAN_FILTER(yymsp[0].minor.yy0) is just the same as BOOLEAN_FILTER
     yygotominor.yy9 = new ProbQuery;
@@ -2277,10 +2288,10 @@ static void yy_reduce(
     delete yymsp[0].minor.yy0;
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2282 "queryparser/queryparser_internal.cc"
+#line 2293 "queryparser/queryparser_internal.cc"
         break;
       case 25:
-#line 1584 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1595 "queryparser/queryparser.lemony"
 {
     // LOVE BOOLEAN_FILTER(yymsp[0].minor.yy0) is just the same as BOOLEAN_FILTER
     yygotominor.yy9 = yymsp[-2].minor.yy9;
@@ -2290,23 +2301,23 @@ static void yy_reduce(
     delete yymsp[0].minor.yy0;
   yy_destructor(8,&yymsp[-1].minor);
 }
-#line 2295 "queryparser/queryparser_internal.cc"
+#line 2306 "queryparser/queryparser_internal.cc"
         break;
       case 26:
-#line 1599 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1610 "queryparser/queryparser.lemony"
 { yygotominor.yy9 = yymsp[0].minor.yy9; }
-#line 2300 "queryparser/queryparser_internal.cc"
+#line 2311 "queryparser/queryparser_internal.cc"
         break;
       case 27:
-#line 1601 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1612 "queryparser/queryparser.lemony"
 {
     yygotominor.yy9 = new ProbQuery;
     yygotominor.yy9->query = yymsp[0].minor.yy13;
 }
-#line 2308 "queryparser/queryparser_internal.cc"
+#line 2319 "queryparser/queryparser_internal.cc"
         break;
       case 28:
-#line 1615 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1626 "queryparser/queryparser.lemony"
 {
     if (state->is_stopword(yymsp[0].minor.yy0)) {
 	yygotominor.yy13 = NULL;
@@ -2316,117 +2327,117 @@ static void yy_reduce(
     }
     delete yymsp[0].minor.yy0;
 }
-#line 2321 "queryparser/queryparser_internal.cc"
+#line 2332 "queryparser/queryparser_internal.cc"
         break;
       case 30:
-#line 1634 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1645 "queryparser/queryparser.lemony"
 {
     yygotominor.yy13 = new Query(yymsp[0].minor.yy0->get_query_with_auto_synonyms());
     delete yymsp[0].minor.yy0;
 }
-#line 2329 "queryparser/queryparser_internal.cc"
+#line 2340 "queryparser/queryparser_internal.cc"
         break;
       case 32:
-#line 1651 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1662 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy0->as_wildcarded_query(state); }
-#line 2334 "queryparser/queryparser_internal.cc"
+#line 2345 "queryparser/queryparser_internal.cc"
         break;
       case 33:
-#line 1654 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1665 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy0->as_partial_query(state); }
-#line 2339 "queryparser/queryparser_internal.cc"
+#line 2350 "queryparser/queryparser_internal.cc"
         break;
       case 34:
-#line 1657 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1668 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[-1].minor.yy1->as_phrase_query();   yy_destructor(19,&yymsp[-2].minor);
   yy_destructor(19,&yymsp[0].minor);
 }
-#line 2346 "queryparser/queryparser_internal.cc"
+#line 2357 "queryparser/queryparser_internal.cc"
         break;
       case 35:
-#line 1660 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1671 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy1->as_phrase_query(); }
-#line 2351 "queryparser/queryparser_internal.cc"
+#line 2362 "queryparser/queryparser_internal.cc"
         break;
       case 36:
-#line 1662 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1673 "queryparser/queryparser.lemony"
 {
     yygotominor.yy13 = yymsp[0].minor.yy60->as_group(state);
 }
-#line 2358 "queryparser/queryparser_internal.cc"
+#line 2369 "queryparser/queryparser_internal.cc"
         break;
       case 37:
-#line 1667 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1678 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy1->as_near_query(); }
-#line 2363 "queryparser/queryparser_internal.cc"
+#line 2374 "queryparser/queryparser_internal.cc"
         break;
       case 38:
-#line 1670 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1681 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[0].minor.yy1->as_adj_query(); }
-#line 2368 "queryparser/queryparser_internal.cc"
+#line 2379 "queryparser/queryparser_internal.cc"
         break;
       case 39:
-#line 1673 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1684 "queryparser/queryparser.lemony"
 { yygotominor.yy13 = yymsp[-1].minor.yy13;   yy_destructor(20,&yymsp[-2].minor);
   yy_destructor(21,&yymsp[0].minor);
 }
-#line 2375 "queryparser/queryparser_internal.cc"
+#line 2386 "queryparser/queryparser_internal.cc"
         break;
       case 40:
-#line 1675 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1686 "queryparser/queryparser.lemony"
 {
     yygotominor.yy13 = new Query(yymsp[0].minor.yy0->get_query_with_synonyms());
     delete yymsp[0].minor.yy0;
   yy_destructor(10,&yymsp[-1].minor);
 }
-#line 2384 "queryparser/queryparser_internal.cc"
+#line 2395 "queryparser/queryparser_internal.cc"
         break;
       case 41:
-#line 1686 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1697 "queryparser/queryparser.lemony"
 {
     yygotominor.yy1 = new TermList;
     yygotominor.yy1->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2392 "queryparser/queryparser_internal.cc"
+#line 2403 "queryparser/queryparser_internal.cc"
         break;
       case 42:
       case 44:
-#line 1691 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1702 "queryparser/queryparser.lemony"
 {
     yygotominor.yy1 = yymsp[-1].minor.yy1;
     yygotominor.yy1->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2401 "queryparser/queryparser_internal.cc"
+#line 2412 "queryparser/queryparser_internal.cc"
         break;
       case 43:
-#line 1703 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1714 "queryparser/queryparser.lemony"
 {
     yygotominor.yy1 = new TermList;
     yygotominor.yy1->add_positional_term(yymsp[-1].minor.yy0);
     yygotominor.yy1->add_positional_term(yymsp[0].minor.yy0);
 }
-#line 2410 "queryparser/queryparser_internal.cc"
+#line 2421 "queryparser/queryparser_internal.cc"
         break;
       case 45:
-#line 1720 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1731 "queryparser/queryparser.lemony"
 {
     yygotominor.yy60 = new TermGroup;
     yygotominor.yy60->add_term(yymsp[-1].minor.yy0);
     yygotominor.yy60->add_term(yymsp[0].minor.yy0);
 }
-#line 2419 "queryparser/queryparser_internal.cc"
+#line 2430 "queryparser/queryparser_internal.cc"
         break;
       case 46:
-#line 1726 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1737 "queryparser/queryparser.lemony"
 {
     yygotominor.yy60 = yymsp[-1].minor.yy60;
     yygotominor.yy60->add_term(yymsp[0].minor.yy0);
 }
-#line 2427 "queryparser/queryparser_internal.cc"
+#line 2438 "queryparser/queryparser_internal.cc"
         break;
       case 47:
       case 49:
-#line 1737 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1748 "queryparser/queryparser.lemony"
 {
     yygotominor.yy1 = new TermList;
     yygotominor.yy1->add_positional_term(yymsp[-2].minor.yy0);
@@ -2436,11 +2447,11 @@ static void yy_reduce(
 	delete yymsp[-1].minor.yy0;
     }
 }
-#line 2441 "queryparser/queryparser_internal.cc"
+#line 2452 "queryparser/queryparser_internal.cc"
         break;
       case 48:
       case 50:
-#line 1747 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1758 "queryparser/queryparser.lemony"
 {
     yygotominor.yy1 = yymsp[-2].minor.yy1;
     yygotominor.yy1->add_positional_term(yymsp[0].minor.yy0);
@@ -2449,7 +2460,7 @@ static void yy_reduce(
 	delete yymsp[-1].minor.yy0;
     }
 }
-#line 2454 "queryparser/queryparser_internal.cc"
+#line 2465 "queryparser/queryparser_internal.cc"
         break;
   }
   yygoto = yyRuleInfo[yyruleno].lhs;
@@ -2474,11 +2485,11 @@ static void yy_parse_failed(
   while( !yypParser->yystack.empty() ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will be executed whenever the
   ** parser fails */
-#line 1323 "/data/home/olly/tmp/xapian-svn-snapshot/tags/1.0.7/xapian/xapian-core/queryparser/queryparser.lemony"
+#line 1334 "queryparser/queryparser.lemony"
 
     // If we've not already set an error message, set a default one.
     if (!state->error) state->error = "parse error";
-#line 2484 "queryparser/queryparser_internal.cc"
+#line 2495 "queryparser/queryparser_internal.cc"
   ParseARG_STORE; /* Suppress warning about unused %extra_argument variable */
 }
 
