@@ -2,7 +2,7 @@
  *
  * Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009 Olly Betts
  * Copyright 2006,2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -26,7 +26,6 @@
 #include "api_anydb.h"
 
 #include <algorithm>
-#include <iomanip>
 #include <string>
 
 #include <xapian.h>
@@ -60,10 +59,12 @@ print_mset_percentages(const Xapian::MSet &mset)
 }
 
 static Xapian::Query
-query(Xapian::Query::op op, string t1 = "", string t2 = "",
-      string t3 = "", string t4 = "", string t5 = "",
-      string t6 = "", string t7 = "", string t8 = "",
-      string t9 = "", string t10 = "")
+query(Xapian::Query::op op,
+      const string & t1 = string(), const string & t2 = string(),
+      const string & t3 = string(), const string & t4 = string(),
+      const string & t5 = string(), const string & t6 = string(),
+      const string & t7 = string(), const string & t8 = string(),
+      const string & t9 = string(), const string & t10 = string())
 {
     vector<string> v;
     Xapian::Stem stemmer("english");
@@ -82,10 +83,11 @@ query(Xapian::Query::op op, string t1 = "", string t2 = "",
 
 static Xapian::Query
 query(Xapian::Query::op op, Xapian::termcount parameter,
-      string t1 = "", string t2 = "",
-      string t3 = "", string t4 = "", string t5 = "",
-      string t6 = "", string t7 = "", string t8 = "",
-      string t9 = "", string t10 = "")
+      const string & t1 = string(), const string & t2 = string(),
+      const string & t3 = string(), const string & t4 = string(),
+      const string & t5 = string(), const string & t6 = string(),
+      const string & t7 = string(), const string & t8 = string(),
+      const string & t9 = string(), const string & t10 = string())
 {
     vector<string> v;
     Xapian::Stem stemmer("english");
@@ -512,8 +514,13 @@ DEFINE_TESTCASE(topercent2, backend) {
     pct = mymset.convert_to_percent(i);
     TEST_EQUAL(pct, 100);
 
-    TEST_EQUAL(mymset, localmset);
-    TEST(mset_range_is_same_percents(mymset, 0, localmset, 0, mymset.size()));
+    TEST_EQUAL(mymset.get_matches_lower_bound(), localmset.get_matches_lower_bound());
+    TEST_EQUAL(mymset.get_matches_upper_bound(), localmset.get_matches_upper_bound());
+    TEST_EQUAL(mymset.get_matches_estimated(), localmset.get_matches_estimated());
+    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), localmset.get_max_attained());
+    TEST_EQUAL_DOUBLE(mymset.get_max_possible(), localmset.get_max_possible());
+    TEST_EQUAL(mymset.size(), localmset.size());
+    TEST(mset_range_is_same(mymset, 0, localmset, 0, mymset.size()));
 
     // A search in which the top document doesn't have 100%
     Xapian::Query q = query(Xapian::Query::OP_OR,
@@ -536,8 +543,13 @@ DEFINE_TESTCASE(topercent2, backend) {
     TEST_GREATER(pct, 40);
     TEST_LESSER(pct, 50);
 
-    TEST_EQUAL(mymset, localmset);
-    TEST(mset_range_is_same_percents(mymset, 0, localmset, 0, mymset.size()));
+    TEST_EQUAL(mymset.get_matches_lower_bound(), localmset.get_matches_lower_bound());
+    TEST_EQUAL(mymset.get_matches_upper_bound(), localmset.get_matches_upper_bound());
+    TEST_EQUAL(mymset.get_matches_estimated(), localmset.get_matches_estimated());
+    TEST_EQUAL_DOUBLE(mymset.get_max_attained(), localmset.get_max_attained());
+    TEST_EQUAL_DOUBLE(mymset.get_max_possible(), localmset.get_max_possible());
+    TEST_EQUAL(mymset.size(), localmset.size());
+    TEST(mset_range_is_same(mymset, 0, localmset, 0, mymset.size()));
 
     return true;
 }
@@ -1267,6 +1279,40 @@ DEFINE_TESTCASE(eliteset4, backend) {
     return true;
 }
 
+/// Regression test for problem with excess precision.
+DEFINE_TESTCASE(eliteset5, backend) {
+    SKIP_TEST_FOR_BACKEND("multi");
+
+    Xapian::Database mydb1(get_database("apitest_simpledata"));
+    Xapian::Enquire enquire1(mydb1);
+
+    vector<string> v;
+    for (int i = 0; i != 3; ++i) {
+	v.push_back("simpl");
+	v.push_back("queri");
+
+	v.push_back("rubbish");
+	v.push_back("rubbish");
+	v.push_back("rubbish");
+	v.push_back("word");
+	v.push_back("word");
+	v.push_back("word");
+    }
+
+    Xapian::Query myquery1 = Xapian::Query(Xapian::Query::OP_ELITE_SET,
+					   v.begin(), v.end(), 1);
+    myquery1 = Xapian::Query(Xapian::Query::OP_SCALE_WEIGHT,
+			     myquery1,
+			     0.004);
+
+    enquire1.set_query(myquery1);
+    // On architectures with excess precision (or, at least, on x86), the
+    // following call used to result in a segfault.
+    enquire1.get_mset(0, 10);
+
+    return true;
+}
+
 /// Test that the termfreq returned by termlists is correct.
 DEFINE_TESTCASE(termlisttermfreq1, backend) {
     Xapian::Database mydb(get_database("apitest_simpledata"));
@@ -1754,19 +1800,20 @@ DEFINE_TESTCASE(checkatleast3, backend) {
 		break;
 	}
 
-	for (int sort = 0; sort < 4; ++sort) {
+	for (int sort = 0; sort < 7; ++sort) {
+	    bool reverse = (sort & 1);
 	    switch (sort) {
 		case 0:
 		    enquire.set_sort_by_relevance();
 		    break;
-		case 1:
-		    enquire.set_sort_by_value(0);
+		case 1: case 2:
+		    enquire.set_sort_by_value(0, reverse);
 		    break;
-		case 2:
-		    enquire.set_sort_by_value_then_relevance(0);
+		case 3: case 4:
+		    enquire.set_sort_by_value_then_relevance(0, reverse);
 		    break;
-		case 3:
-		    enquire.set_sort_by_relevance_then_value(0);
+		case 5: case 6:
+		    enquire.set_sort_by_relevance_then_value(0, reverse);
 		    break;
 	    }
 
