@@ -1,7 +1,7 @@
 /** @file backendmanager_remotetcp.cc
  * @brief BackendManager subclass for remotetcp databases.
  */
-/* Copyright (C) 2006,2007,2008 Olly Betts
+/* Copyright (C) 2006,2007,2008,2009 Olly Betts
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -69,7 +69,7 @@ using namespace std;
 
 // We can't dynamically allocate memory for this because it confuses the leak
 // detector.  We only have 1-3 child fds open at once anyway, so a fixed size
-// array isn't a problem, and linear scanning isn't a problem.
+// array isn't a problem, and linear scanning isn't a problem either.
 struct pid_fd {
     pid_t pid;
     int fd;
@@ -77,7 +77,9 @@ struct pid_fd {
 
 static pid_fd pid_to_fd[16];
 
-extern "C" void
+extern "C" {
+
+static void
 on_SIGCHLD(int /*sig*/)
 {
     int status;
@@ -86,8 +88,8 @@ on_SIGCHLD(int /*sig*/)
 	for (unsigned i = 0; i < sizeof(pid_to_fd) / sizeof(pid_fd); ++i) {
 	    if (pid_to_fd[i].pid == child) {
 		int fd = pid_to_fd[i].fd;
-		pid_to_fd[i].fd = -1;
-		pid_to_fd[i].pid = -1;
+		pid_to_fd[i].fd = 0;
+		pid_to_fd[i].pid = 0;
 		// NB close() *is* safe to use in a signal handler.
 		close(fd);
 		break;
@@ -96,13 +98,15 @@ on_SIGCHLD(int /*sig*/)
     }
 }
 
+}
+
 static int
 launch_xapian_tcpsrv(const string & args)
 {
     int port = DEFAULT_PORT;
 
     // We want to be able to get the exit status of the child process we fork
-    // in xapian-tcpsrv doesn't start listening successfully.
+    // if xapian-tcpsrv doesn't start listening successfully.
     signal(SIGCHLD, SIG_DFL);
 try_next_port:
     string cmd = XAPIAN_TCPSRV" --one-shot --interface "LOCALHOST" --port " + om_tostring(port) + " " + args;
@@ -148,11 +152,13 @@ try_next_port:
 	msg += strerror(errno);
 	throw msg;
     }
+
     string output;
     while (true) {
 	char buf[256];
 	if (fgets(buf, sizeof(buf), fh) == NULL) {
 	    fclose(fh);
+	    // Wait for the child to exit.
 	    int status;
 	    if (waitpid(child, &status, 0) == -1) {
 		string msg("waitpid failed: ");
@@ -189,7 +195,7 @@ try_next_port:
     // Find a slot to track the pid->fd mapping in.  If we can't find a slot
     // it just means we'll leak the fd, so don't worry about that too much.
     for (unsigned i = 0; i < sizeof(pid_to_fd) / sizeof(pid_fd); ++i) {
-	if (pid_to_fd[i].pid == -1) {
+	if (pid_to_fd[i].pid == 0) {
 	    pid_to_fd[i].fd = tracked_fd;
 	    pid_to_fd[i].pid = child;
 	    break;
@@ -305,7 +311,9 @@ try_next_port:
 # error Neither HAVE_FORK nor __WIN32__ is defined
 #endif
 
-BackendManagerRemoteTcp::~BackendManagerRemoteTcp() { }
+BackendManagerRemoteTcp::~BackendManagerRemoteTcp() {
+    BackendManagerRemoteTcp::clean_up();
+}
 
 const char *
 BackendManagerRemoteTcp::get_dbtype() const
@@ -341,7 +349,7 @@ BackendManagerRemoteTcp::get_writable_database(const string & name,
     (void)getwritedb_flint(name, vector<string>(1, file));
     args += ".flint/";
 #else
-    (void)getwritedb_quartz(vector<string>(1, file));
+    (void)getwritedb_quartz(name, vector<string>(1, file));
     args += ".quartz/";
 #endif
     args += name;
@@ -396,3 +404,26 @@ BackendManagerRemoteTcp::get_writable_database_again()
     int port = launch_xapian_tcpsrv(args);
     return Xapian::Remote::open_writable(LOCALHOST, port);
 }
+
+void
+BackendManagerRemoteTcp::clean_up()
+{
+#ifdef HAVE_FORK
+    signal(SIGCHLD, SIG_DFL);
+    for (unsigned i = 0; i < sizeof(pid_to_fd) / sizeof(pid_fd); ++i) {
+	pid_t child = pid_to_fd[i].pid;
+	if (child) {
+	    int status;
+	    while (waitpid(child, &status, 0) == -1 && errno == EINTR) { }
+	    // Other possible error from waitpid is ECHILD, which it seems can
+	    // only mean that the child has already exited and SIGCHLD was set
+	    // to SIG_IGN.  If we did somehow see that, the sanest response
+	    // seems to be to close the fd and move on.
+	    int fd = pid_to_fd[i].fd;
+	    pid_to_fd[i].fd = 0;
+	    pid_to_fd[i].pid = 0;
+	    close(fd);
+	}
+    }
+#endif
+}
